@@ -3,7 +3,6 @@ package AnyEvent::WebSocket::Client;
 use strict;
 use warnings;
 use Moo;
-use warnings NONFATAL => 'all';
 use AE;
 use AnyEvent;
 use AnyEvent::Handle;
@@ -13,7 +12,7 @@ use AnyEvent::WebSocket::Connection;
 use PerlX::Maybe qw( maybe provided );
 
 # ABSTRACT: WebSocket client for AnyEvent
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.30'; # VERSION
 
 
 has timeout => (
@@ -116,7 +115,7 @@ AnyEvent::WebSocket::Client - WebSocket client for AnyEvent
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -310,9 +309,9 @@ L<RFC 6455 The WebSocket Protocol|http://tools.ietf.org/html/rfc6455>
 
 =head1 AUTHOR
 
-author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Toshio Ito
 
